==> libgphoto2-2.5.2.tar.bz2: libgphoto2-api.html/gphoto2-port_8h.js <==
var gphoto2-port_8h =
[
    [ "_GPPortSettingsSerial", "struct__GPPortSettingsSerial.html", "struct__GPPortSettingsSerial" ],
    [ "_GPPortSettingsUSB", "struct__GPPortSettingsUSB.html", "struct__GPPortSettingsUSB" ],
    [ "_GPPortSettingsUsbDiskDirect", "struct__GPPortSettingsUsbDiskDirect.html", "struct__GPPortSettingsUsbDiskDirect" ],
    [ "_GPPortSettingsUsbScsi", "struct__GPPortSettingsUsbScsi.html", "struct__GPPortSettingsUsbScsi" ],
    [ "_GPPortSettings", "union__GPPortSettings.html", "union__GPPortSettings" ],
    [ "_GPPort", "struct__GPPort.html", "struct__GPPort" ],
    [ "FALSE", "gphoto2-port_8h.html#aa93f0eb578d23995850d61f7d61c55c1", null ],
    [ "GP_PORT_MAX_BUF_LEN", "gphoto2-port_8h.html#a47331c65bcadc27c28c990970be8f283", null ],
    [ "PIN_CTS", "gphoto2-port_8h.html#adb2ae40535faea274ca0040c5ef34379", null ],
    [ "TRUE", "gphoto2-port_8h.html#aa8cecfc5c5c054d2875c03e77b7be15d", null ],
    [ "gp_port", "gphoto2-port_8h.html#a7e54aca147b086396923889a966acaf3", null ],
    [ "gp_port_settings", "gphoto2-port_8h.html#a42b49c0d94d2411a10e73b6b2614add7", null ],
    [ "GPLevel", "gphoto2-port_8h.html#a90a6e780088b49cab02e43a562799214", null ],
    [ "GPPin", "gphoto2-port_8h.html#a5d7a807362bec34668a61606007c4c98", null ],
    [ "GPPort", "gphoto2-port_8h.html#ac414204e7ed8565299106f6589bc0e4d", null ],
    [ "GPPortPrivateCore", "gphoto2-port_8h.html#a52a214e8f6d8484669cc8413af3fd5eb", null ],
    [ "GPPortPrivateLibrary", "gphoto2-port_8h.html#a821f43556fd6466947ee1279fd00d136", null ],
    [ "GPPortSerialParity", "gphoto2-port_8h.html#a73c8cda29a595f4b659c73be294771cb", null ],
    [ "GPPortSettings", "gphoto2-port_8h.html#a731d001407c1e84d9c1e258a9f7723bb", null ],
    [ "GPPortSettingsSerial", "gphoto2-port_8h.html#a41defe822e82d273bc430955205887a0", null ],
    [ "GPPortSettingsUSB", "gphoto2-port_8h.html#a27e898f4dd7b1f6886bb81332ea074a2", null ],
    [ "GPPortSettingsUsbDiskDirect", "gphoto2-port_8h.html#a5df4c06cbbf9d419c3dc4b13e37e121f", null ],
    [ "GPPortSettingsUsbScsi", "gphoto2-port_8h.html#ae6a95d6308595d79576e79e6986c30b2", null ],
    [ "_GPLevel", "gphoto2-port_8h.html#a94aef01d47cdb21a645475901751a92a", null ],
    [ "_GPPin", "gphoto2-port_8h.html#aa94b9e7933d1f0e5fc540660c25aa7c8", null ],
    [ "_GPPortSerialParity", "gphoto2-port_8h.html#a0154b05219003ef2fac2b490623613fb", null ],
    [ "gp_port_check_int", "gphoto2-port_8h.html#a0077bb0c6918d27e5a36f27087e2c277", null ],
    [ "gp_port_check_int_fast", "gphoto2-port_8h.html#aa3ac8ac353d96106575bf951f997276c", null ],
    [ "gp_port_close", "gphoto2-port_8h.html#ac474f719cd32a6dec42eef980f20f71e", null ],
    [ "gp_port_flush", "gphoto2-port_8h.html#ac85bf5c84f52b34a8ef9c1d71de2ff5d", null ],
    [ "gp_port_free", "gphoto2-port_8h.html#ab1274205cd3baa2905d0edd78429bcb5", null ],
    [ "gp_port_get_error", "gphoto2-port_8h.html#a9e38b6166cea9b54c8b7637cac740828", null ],
    [ "gp_port_get_info", "gphoto2-port_8h.html#a247bb45fcf90021f45ae137df40dd47a", null ],
    [ "gp_port_get_pin", "gphoto2-port_8h.html#a78fda26011604ff372d9a1a7ff83bc62", null ],
    [ "gp_port_get_settings", "gphoto2-port_8h.html#aa9dffcdab4b918d2dc2b7d6015c63fb0", null ],
    [ "gp_port_get_timeout", "gphoto2-port_8h.html#a2ae81836b1bca7ae97695d754cc9a3a6", null ],
    [ "gp_port_new", "gphoto2-port_8h.html#a7a8d75aa016e04b9c0d3b7849681ebe5", null ],
    [ "gp_port_open", "gphoto2-port_8h.html#a976f2b7d7c2bd3f5399a6f5829044957", null ],
    [ "gp_port_read", "gphoto2-port_8h.html#a8f66d05b6a22677ef689180eacb2f85d", null ],
    [ "gp_port_reset", "gphoto2-port_8h.html#a0d9ec033ed72d9fb9e29bfd8d4010c44", null ],
    [ "gp_port_seek", "gphoto2-port_8h.html#ac55c6bd131ac7ab047d8867c853b1bda", null ],
    [ "gp_port_send_break", "gphoto2-port_8h.html#aa5c3be2ad2546c829dc21d4d8fabb08d", null ],
    [ "gp_port_send_scsi_cmd", "gphoto2-port_8h.html#a56b83abbf58d7b01bdfd568bc3fff917", null ],
    [ "gp_port_set_error", "gphoto2-port_8h.html#a99a4671624d0b4d5f86cb5aaf94941fb", null ],
    [ "gp_port_set_info", "gphoto2-port_8h.html#a4a192eaac78b326ebe41e8e4441a38e4", null ],
    [ "gp_port_set_pin", "gphoto2-port_8h.html#afb74e804c7fdb8897736f811d8e2adae", null ],
    [ "gp_port_set_settings", "gphoto2-port_8h.html#a9503a6f8c4d87a2c22b802ce099cf8ef", null ],
    [ "gp_port_set_timeout", "gphoto2-port_8h.html#a68fb24a4f729ec5be85f4aedf3bb8e4f", null ],
    [ "gp_port_usb_clear_halt", "gphoto2-port_8h.html#af410cacf6d6c44325b6637da95fc574d", null ],
    [ "gp_port_usb_find_device", "gphoto2-port_8h.html#a790fff9ba13a8b2730cdc1213ec98d48", null ],
    [ "gp_port_usb_find_device_by_class", "gphoto2-port_8h.html#a5d67338933ddaed39c4fb20a23d76ec2", null ],
    [ "gp_port_usb_msg_class_read", "gphoto2-port_8h.html#a0cbdaa571a0eef7441fee91a244e21f2", null ],
    [ "gp_port_usb_msg_class_write", "gphoto2-port_8h.html#a283ebf127e608cc77b137103bbde3caf", null ],
    [ "gp_port_usb_msg_interface_read", "gphoto2-port_8h.html#a946715a386d9280d71b4ec58488aabd4", null ],
    [ "gp_port_usb_msg_interface_write", "gphoto2-port_8h.html#a4fbc4a2c1583e25d5e220b757375f305", null ],
    [ "gp_port_usb_msg_read", "gphoto2-port_8h.html#a2e5d3e6f918acb16e8ee6996018507a6", null ],
    [ "gp_port_usb_msg_write", "gphoto2-port_8h.html#a1118c50abbdf1926d6e08e0b6bb1209d", null ],
    [ "gp_port_write", "gphoto2-port_8h.html#a08cc8e20df73217baeafccbc71ba9897", null ]
];

==> libgphoto2_2.5.24.orig.tar.bz2: libgphoto2-api.html/gphoto2-port_8h.js <==
var gphoto2_port_8h =
[
    [ "_GPPortSettingsSerial", "struct__GPPortSettingsSerial.html", "struct__GPPortSettingsSerial" ],
    [ "_GPPortSettingsUSB", "struct__GPPortSettingsUSB.html", "struct__GPPortSettingsUSB" ],
    [ "_GPPortSettingsUsbDiskDirect", "struct__GPPortSettingsUsbDiskDirect.html", "struct__GPPortSettingsUsbDiskDirect" ],
    [ "_GPPortSettingsUsbScsi", "struct__GPPortSettingsUsbScsi.html", "struct__GPPortSettingsUsbScsi" ],
    [ "_GPPortSettings", "union__GPPortSettings.html", "union__GPPortSettings" ],
    [ "_GPPort", "struct__GPPort.html", "struct__GPPort" ],
    [ "FALSE", "gphoto2-port_8h.html#aa93f0eb578d23995850d61f7d61c55c1", null ],
    [ "GP_PORT_MAX_BUF_LEN", "gphoto2-port_8h.html#a47331c65bcadc27c28c990970be8f283", null ],
    [ "PIN_CTS", "gphoto2-port_8h.html#adb2ae40535faea274ca0040c5ef34379", null ],
    [ "TRUE", "gphoto2-port_8h.html#aa8cecfc5c5c054d2875c03e77b7be15d", null ],
    [ "gp_port", "gphoto2-port_8h.html#a7e54aca147b086396923889a966acaf3", null ],
    [ "gp_port_settings", "gphoto2-port_8h.html#a42b49c0d94d2411a10e73b6b2614add7", null ],
    [ "GPLevel", "gphoto2-port_8h.html#a90a6e780088b49cab02e43a562799214", null ],
    [ "GPPin", "gphoto2-port_8h.html#a5d7a807362bec34668a61606007c4c98", null ],
    [ "GPPort", "gphoto2-port_8h.html#ac414204e7ed8565299106f6589bc0e4d", null ],
    [ "GPPortPrivateCore", "gphoto2-port_8h.html#a52a214e8f6d8484669cc8413af3fd5eb", null ],
    [ "GPPortPrivateLibrary", "gphoto2-port_8h.html#a821f43556fd6466947ee1279fd00d136", null ],
    [ "GPPortSerialParity", "gphoto2-port_8h.html#a73c8cda29a595f4b659c73be294771cb", null ],
    [ "GPPortSettings", "gphoto2-port_8h.html#a731d001407c1e84d9c1e258a9f7723bb", null ],
    [ "GPPortSettingsSerial", "gphoto2-port_8h.html#a41defe822e82d273bc430955205887a0", null ],
    [ "GPPortSettingsUSB", "gphoto2-port_8h.html#a27e898f4dd7b1f6886bb81332ea074a2", null ],
    [ "GPPortSettingsUsbDiskDirect", "gphoto2-port_8h.html#a5df4c06cbbf9d419c3dc4b13e37e121f", null ],
    [ "GPPortSettingsUsbScsi", "gphoto2-port_8h.html#ae6a95d6308595d79576e79e6986c30b2", null ],
    [ "GP_PORT_USB_ENDPOINT_IN", "gphoto2-port_8h.html#adf764cbdea00d65edcd07bb9953ad2b7ae0d0fa501434e9a8cd10612d461003f6", null ],
    [ "GP_PORT_USB_ENDPOINT_OUT", "gphoto2-port_8h.html#adf764cbdea00d65edcd07bb9953ad2b7a55a8c1cb0cd0357ebc725f2cc75f9485", null ],
    [ "GP_PORT_USB_ENDPOINT_INT", "gphoto2-port_8h.html#adf764cbdea00d65edcd07bb9953ad2b7aa32d55aa89d8f807b76306a42670306a", null ],
    [ "_GPLevel", "gphoto2-port_8h.html#a94aef01d47cdb21a645475901751a92a", [
      [ "GP_LEVEL_LOW", "gphoto2-port_8h.html#a94aef01d47cdb21a645475901751a92aad4b56e3690d434160baac2d4236454a6", null ],
      [ "GP_LEVEL_HIGH", "gphoto2-port_8h.html#a94aef01d47cdb21a645475901751a92aa36b93ac460c36ca2d335310dde15d2c3", null ]
    ] ],
    [ "_GPPin", "gphoto2-port_8h.html#aa94b9e7933d1f0e5fc540660c25aa7c8", [
      [ "GP_PIN_RTS", "gphoto2-port_8h.html#aa94b9e7933d1f0e5fc540660c25aa7c8ac03fe6b221b0c2516bd9331938056650", null ],
      [ "GP_PIN_DTR", "gphoto2-port_8h.html#aa94b9e7933d1f0e5fc540660c25aa7c8a292f1601797289084f01d82978c9191c", null ],
      [ "GP_PIN_CTS", "gphoto2-port_8h.html#aa94b9e7933d1f0e5fc540660c25aa7c8a3a985fc082f2a3f5ec80a5927dbfb97f", null ],
      [ "GP_PIN_DSR", "gphoto2-port_8h.html#aa94b9e7933d1f0e5fc540660c25aa7c8aaa8af6fa656e2f94e88f9e87e076641b", null ],
      [ "GP_PIN_CD", "gphoto2-port_8h.html#aa94b9e7933d1f0e5fc540660c25aa7c8a1bfa9d2a14f677b059de1e217c96c610", null ],
      [ "GP_PIN_RING", "gphoto2-port_8h.html#aa94b9e7933d1f0e5fc540660c25aa7c8ad97001a403a4ee2e1bb7b943ce60e2c3", null ]
    ] ],
    [ "_GPPortSerialParity", "gphoto2-port_8h.html#a0154b05219003ef2fac2b490623613fb", [
      [ "GP_PORT_SERIAL_PARITY_OFF", "gphoto2-port_8h.html#a0154b05219003ef2fac2b490623613fbadea6c7888c5b3d31fc58a97400003e4a", null ],
      [ "GP_PORT_SERIAL_PARITY_EVEN", "gphoto2-port_8h.html#a0154b05219003ef2fac2b490623613fba6817c46c2ee6caea47b010305d6640ca", null ],
      [ "GP_PORT_SERIAL_PARITY_ODD", "gphoto2-port_8h.html#a0154b05219003ef2fac2b490623613fba011c902e5923e373cf1a36de818c4886", null ]
    ] ],
    [ "gp_port_check_int", "gphoto2-port_8h.html#a0077bb0c6918d27e5a36f27087e2c277", null ],
    [ "gp_port_check_int_fast", "gphoto2-port_8h.html#aa3ac8ac353d96106575bf951f997276c", null ],
    [ "gp_port_close", "gphoto2-port_8h.html#ac474f719cd32a6dec42eef980f20f71e", null ],
    [ "gp_port_flush", "gphoto2-port_8h.html#ac85bf5c84f52b34a8ef9c1d71de2ff5d", null ],
    [ "gp_port_free", "gphoto2-port_8h.html#ab1274205cd3baa2905d0edd78429bcb5", null ],
    [ "gp_port_get_error", "gphoto2-port_8h.html#a9e38b6166cea9b54c8b7637cac740828", null ],
    [ "gp_port_get_info", "gphoto2-port_8h.html#a247bb45fcf90021f45ae137df40dd47a", null ],
    [ "gp_port_get_pin", "gphoto2-port_8h.html#a78fda26011604ff372d9a1a7ff83bc62", null ],
    [ "gp_port_get_settings", "gphoto2-port_8h.html#aa9dffcdab4b918d2dc2b7d6015c63fb0", null ],
    [ "gp_port_get_timeout", "gphoto2-port_8h.html#a2ae81836b1bca7ae97695d754cc9a3a6", null ],
    [ "gp_port_new", "gphoto2-port_8h.html#a7a8d75aa016e04b9c0d3b7849681ebe5", null ],
    [ "gp_port_open", "gphoto2-port_8h.html#a976f2b7d7c2bd3f5399a6f5829044957", null ],
    [ "gp_port_read", "gphoto2-port_8h.html#a8f66d05b6a22677ef689180eacb2f85d", null ],
    [ "gp_port_reset", "gphoto2-port_8h.html#a0d9ec033ed72d9fb9e29bfd8d4010c44", null ],
    [ "gp_port_seek", "gphoto2-port_8h.html#ac55c6bd131ac7ab047d8867c853b1bda", null ],
    [ "gp_port_send_break", "gphoto2-port_8h.html#aa5c3be2ad2546c829dc21d4d8fabb08d", null ],
    [ "gp_port_send_scsi_cmd", "gphoto2-port_8h.html#a56b83abbf58d7b01bdfd568bc3fff917", null ],
    [ "gp_port_set_error", "gphoto2-port_8h.html#a99a4671624d0b4d5f86cb5aaf94941fb", null ],
    [ "gp_port_set_info", "gphoto2-port_8h.html#a4a192eaac78b326ebe41e8e4441a38e4", null ],
    [ "gp_port_set_pin", "gphoto2-port_8h.html#afb74e804c7fdb8897736f811d8e2adae", null ],
    [ "gp_port_set_settings", "gphoto2-port_8h.html#a9503a6f8c4d87a2c22b802ce099cf8ef", null ],
    [ "gp_port_set_timeout", "gphoto2-port_8h.html#a68fb24a4f729ec5be85f4aedf3bb8e4f", null ],
    [ "gp_port_usb_clear_halt", "gphoto2-port_8h.html#af410cacf6d6c44325b6637da95fc574d", null ],
    [ "gp_port_usb_find_device", "gphoto2-port_8h.html#a790fff9ba13a8b2730cdc1213ec98d48", null ],
    [ "gp_port_usb_find_device_by_class", "gphoto2-port_8h.html#a5d67338933ddaed39c4fb20a23d76ec2", null ],
    [ "gp_port_usb_msg_class_read", "gphoto2-port_8h.html#a0cbdaa571a0eef7441fee91a244e21f2", null ],
    [ "gp_port_usb_msg_class_write", "gphoto2-port_8h.html#a283ebf127e608cc77b137103bbde3caf", null ],
    [ "gp_port_usb_msg_interface_read", "gphoto2-port_8h.html#a946715a386d9280d71b4ec58488aabd4", null ],
    [ "gp_port_usb_msg_interface_write", "gphoto2-port_8h.html#a4fbc4a2c1583e25d5e220b757375f305", null ],
    [ "gp_port_usb_msg_read", "gphoto2-port_8h.html#a2e5d3e6f918acb16e8ee6996018507a6", null ],
    [ "gp_port_usb_msg_write", "gphoto2-port_8h.html#a1118c50abbdf1926d6e08e0b6bb1209d", null ],
    [ "gp_port_write", "gphoto2-port_8h.html#a08cc8e20df73217baeafccbc71ba9897", null ]
];
